package org.example.NisumSearchPage;


import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.openqa.selenium.*;
import org.openqa.selenium.interactions.Actions;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.time.Duration;

public class NisumPage {
    WebDriver driver;

    private static final Logger log = LogManager.getLogger(NisumPage.class);


    public NisumPage(WebDriver driver) {
        this.driver = driver;
        log.info("NisumPage object created with WebDriver instance.");
    }

    By searchBox = By.name("q");
    By nisumFirstLink = By.xpath("//a[@href='https://www.nisum.com/']//h3[@class='LC20lb MBeuO DKV0Md'][normalize-space()='Nisum | A Technology Consulting Partner']");
    By globalCareersBtn = By.xpath("//span[@class='mega-drop-4 loaded']");
    By pakistanCareersBtn = By.xpath("//li[@class='hs-menu-item hs-menu-depth-1 hs-item-has-children']//a[@role='menuitem'][normalize-space()='Pakistan']");

    // Search for text
    public void searchForText(String searchText) {
        try {
            log.info("Attempting to search for the term: " + searchText);
            WebElement searchField = driver.findElement(searchBox);
            searchField.sendKeys(searchText);
            log.info("Search text '" + searchText + "' entered in search box.");
            searchField.submit();
            log.info("Search for '" + searchText + "' submitted.");
        } catch (Exception e) {
            //log.severe("Error occurred while attempting to search for '" + searchText + "': " + e.getMessage());
        }
    }

    // Click on the first link
    public void clickFirstLink() {
        log.info("Attempting to click the first link for Nisum website.");
        WebElement firstLink = driver.findElement(nisumFirstLink);
        firstLink.click();
        log.info("Clicked on the first Nisum website link.");
    }

    // Hover over Global Careers button
    public void hoverOverGlobalCareers() {
        try {
            log.info("Attempting to hover over the Global Careers button.");

            WebElement globalCareers = driver.findElement(globalCareersBtn);
            Actions actions = new Actions(driver);

            // Hovering over the element
            actions.moveToElement(globalCareers).perform();
            log.info("Hovered over the Global Careers button.");
        } catch (Exception e) {
            // log.severe("Error occurred while attempting to hover over the Global Careers button: " + e.getMessage());
        }
    }

    public void clickPakistanCareers() {
        log.info("Attempting to click on the Pakistan Careers button.");

        try {
            // Wait for the element to be clickable
            WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(10));
            WebElement element = wait.until(ExpectedConditions.elementToBeClickable(pakistanCareersBtn));

            log.info("Element is clickable. Attempting to scroll into view.");

            // Scroll the element into view using JavaScript
            ((JavascriptExecutor) driver).executeScript("arguments[0].scrollIntoView(true);", element);

            // Pause briefly to ensure scrolling is completed
            Thread.sleep(500);

            log.info("Attempting to click using JavaScript.");

            // Click the element using JavaScript to avoid interception
            ((JavascriptExecutor) driver).executeScript("arguments[0].click();", element);

            log.info("Successfully clicked the Pakistan Careers button.");

        } catch (ElementClickInterceptedException e) {
            log.error("ElementClickInterceptedException occurred. Retrying with JavaScript click.", e);

            // If element is intercepted by another element, retry with JavaScript click
            WebElement element = driver.findElement(pakistanCareersBtn);
            ((JavascriptExecutor) driver).executeScript("arguments[0].click();", element);

        } catch (InterruptedException e) {
            log.error("InterruptedException during scroll wait.", e);
            Thread.currentThread().interrupt();
        } catch (Exception e) {
            log.error("An unexpected error occurred while clicking Pakistan Careers.", e);
        }
    }
}
