package org.example.OpenAI;

import com.fasterxml.jackson.databind.ObjectMapper;
import okhttp3.*;
import org.json.simple.JSONArray;
import org.json.simple.JSONObject;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class OpenAISuggestions {

    private static final String API_URL = "https://generativelanguage.googleapis.com/v1beta/models/gemini-1.5-flash:generateContent?key=AIzaSyDwyMA69dj-7tejDr7iVlKzU0Y86OGMAZ0";
    private final OkHttpClient client = new OkHttpClient();
    private final ObjectMapper objectMapper = new ObjectMapper(); // Jackson object mapper for JSON

    public Map<String, Object> getSuggestions(String errorLog) throws IOException {
        Map<String, Object> jsonBody = new HashMap<>();
        Map<String, Object> part = new HashMap<>();
        part.put("text", errorLog);

        Map<String, Object> content = new HashMap<>();
        content.put("parts", List.of(part));

        jsonBody.put("contents", List.of(content));

        RequestBody body = RequestBody.create(
                objectMapper.writeValueAsString(jsonBody),
                MediaType.get("application/json; charset=utf-8")
        );

        Request request = new Request.Builder()
                .url(API_URL)
                .post(body)
                .build();

        try (Response response = client.newCall(request).execute()) {
            if (!response.isSuccessful()) {
                throw new IOException("Unexpected response code: " + response);
            }

            String responseBody = response.body().string();
            return parseResponse(responseBody); // Parse the response
        }
    }

    private Map<String, Object> parseResponse(String responseBody) throws IOException {
        Map<String, Object> responseMap = objectMapper.readValue(responseBody, Map.class);

        List<Map<String, Object>> candidates = (List<Map<String, Object>>) responseMap.get("candidates");
        Map<String, Object> result = new HashMap<>();

        if (candidates != null && !candidates.isEmpty()) {
            Map<String, Object> firstCandidate = candidates.get(0);
            Map<String, Object> content = (Map<String, Object>) firstCandidate.get("content");
            List<Map<String, Object>> parts = (List<Map<String, Object>>) content.get("parts");

            if (parts != null && !parts.isEmpty()) {
                Map<String, Object> firstPart = parts.get(0);
                String suggestion = (String) firstPart.getOrDefault("text", "No suggestions found.");
                result.put("suggestion", suggestion.trim());
            } else {
                result.put("suggestion", "No suggestions found.");
            }
        } else {
            result.put("suggestion", "No suggestions found.");
        }

        return result;
    }
}
